
# Type: population to population association_object




URI: [biolink:population_to_population_association_object](https://w3id.org/biolink/vocab/population_to_population_association_object)


## Domain and Range

[PopulationToPopulationAssociation](PopulationToPopulationAssociation.md) ->  <sub>REQ</sub> [PopulationOfIndividualOrganisms](PopulationOfIndividualOrganisms.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [PopulationToPopulationAssociation](PopulationToPopulationAssociation.md)
